==> xfc-4.3.0.tar.bz2: xfc-4.3.0/libXFCui/xfc/atk/registry.cc <==
/*  XFC: Xfce Foundation Classes (User Interface Library)
 *  Copyright (C) 2004 The XFC Development Team.
 *
 *  registry.cc - AtkRegistry C++ wrapper implementation
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#include "registry.hh"
#include "private/registryclass.hh"
#include "objectfactory.hh"

using namespace Xfc;

/*  Atk::Registry
 */

Atk::Registry::Registry(AtkRegistry *registry, bool owns_reference)
: G::Object((GObject*)registry, owns_reference)
{
}
	
Atk::Registry::~Registry()
{
}
	
Atk::Registry*
Atk::Registry::get_default()
{
	return G::Object::wrap<Registry>(atk_get_default_registry());
}

Atk::ObjectFactory*
Atk::Registry::get_factory(GType type) const
{
	return G::Object::wrap<ObjectFactory>(atk_registry_get_factory(atk_registry(), type));
}

/*  Atk::RegistryClass
 */

GType
Atk::RegistryClass::get_type()
{
	static GType type = 0;
	if (!type)
	{
		type = G::TypeInstance::register_type(ATK_TYPE_REGISTRY);
	}
	return type;
}

void*
Atk::RegistryClass::create()
{
	return g_object_new(get_type(), 0);
}

==> xfc-4.3.1.tar.bz2: xfc-4.3.1/libXFCui/xfc/atk/registry.cc <==
/*  XFC: Xfce Foundation Classes (User Interface Library)
 *  Copyright (C) 2004-2005 The XFC Development Team.
 *
 *  registry.cc - AtkRegistry C++ wrapper implementation
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#include "registry.hh"
#include "private/registryclass.hh"
#include "objectfactory.hh"

using namespace Xfc;

/*  Atk::Registry
 */

Atk::Registry::Registry(AtkRegistry *registry, bool owns_reference)
: G::Object((GObject*)registry, owns_reference)
{
}
	
Atk::Registry::~Registry()
{
}
	
Atk::Registry*
Atk::Registry::get_default()
{
	return G::Object::wrap<Registry>(atk_get_default_registry());
}

Atk::ObjectFactory*
Atk::Registry::get_factory(GType type) const
{
	return G::Object::wrap<ObjectFactory>(atk_registry_get_factory(atk_registry(), type));
}

/*  Atk::RegistryClass
 */

void
Atk::RegistryClass::init(AtkRegistryClass *g_class)
{
	G::ObjectClass::init((GObjectClass*)g_class);
}

GType
Atk::RegistryClass::get_type()
{
	static GType type = 0;
	if (!type)
	{
		type = G::TypeInstance::register_type(ATK_TYPE_REGISTRY, (GClassInitFunc)&init);
	}
	return type;
}

void*
Atk::RegistryClass::create()
{
	return g_object_new(get_type(), 0);
}
